@@ -16,14 +16,14 @@ our @EXPORT = qw(
 );
 
 # ABSTRACT: Check that a library is available for FFI
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.16'; # VERSION
 
 
 our $system_path;
-our $os = $ENV{FFI_CHECKLIB_TEST_OS} || $^O;
-our $dyna_loader = 'DynaLoader';
+our $os ||= $^O;
+our $dyna_loader ||= 'DynaLoader';
 
-if($os eq 'MSWin32')
+if($os eq 'MSWin32' || $os eq 'msys')
 {
   $system_path = eval q{
     use Env qw( @PATH );
@@ -44,6 +44,13 @@ if($os eq 'cygwin')
 {
   push @$pattern, qr{^cyg(.*?)(?:-[0-9]+)?\.dll$};
 }
+elsif($os eq 'msys')
+{
+  # doesn't seem as though msys uses psudo libfoo.so files
+  # in the way that cygwin sometimes does.  we can revisit
+  # this if we find otherwise.
+  $pattern = [ qr{^msys-(.*?)(?:-[0-9]+)?\.dll$} ];
+}
 elsif($os eq 'MSWin32')
 {
   $pattern = [ qr{^(?:lib)?(.*?)(?:-[0-9]+)?\.dll$} ];
@@ -250,7 +257,7 @@ FFI::CheckLib - Check that a library is available for FFI
 
 =head1 VERSION
 
-version 0.14
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -275,9 +282,8 @@ directly into L<FFI::Platypus> or L<FFI::Raw>.
 
 Although intended mainly for FFI modules via L<FFI::Platypus> and 
 similar, this module does not actually use any FFI to do its detection 
-and probing.  This modules does not have any non-core dependencies on 
-Perls 5.8-5.18.  On Perl 5.20 and newer it has a configure, build and 
-test dependency on L<Module::Build>.
+and probing.  This module does not have any non-core runtime dependencies.
+The test suite does depend on L<Test2::Suite>.
 
 =head1 FUNCTIONS
 
@@ -409,6 +415,8 @@ Contributors:
 
 Bakkiaraj Murugesan (bakkiaraj)
 
+Dan Book (grinnz, DBOOK)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Graham Ollis.
